---
title: 토스페이먼츠_허브형 간편결제 추가 방법 안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 간편결제
seo:
  title: 토스페이먼츠_허브형 간편결제 추가 방법 안내
  description: |
    토스페이먼츠에 이미 가입되어 있으신 경우,
    토스페이먼츠측에 간편결제 추가계약 절차가 필요 합니다!
tags:
  - 간편결제
  - 토스페이먼츠
pgCompanies:
  - 토스페이먼츠
searchTags:
  - 추가계약
  - 간편결제 추가
  - 간편결제
  - 허브형
  - 토스페이먼츠
datetime: 2024-07-10T07:39:34.415Z
---

<Callout content=" 토스페이먼츠에 이미 가입되어 있으신 경우, 
토스페이먼츠측에 간편결제 추가계약 절차가 필요 합니다!" />

### 토스페이먼츠 추가계약 절차

- 토스페이먼츠 홈페이지 <https://www.tosspayments.com/> 접속 > 기존 토스페이먼츠 계정 로그인
- 로그인 후 화면 하단 "전자결제 신청" 선택
- 사업자등록번호 입력
- 호스팅사에서 제공하는 쇼핑몰 구축 서비스를 이용 중이신가요? > “네” 선택
- 이용중인 호스팅사를 선택하세요 > "\[다른 업체 검색]" 선택 후 검색란에 "포트원(간편결제)" 입력
- 검색된 리스트 중 "포트원(간편결제)" 선택

신청접수가 완료되면 토스페이먼츠 담당자가 계약절차 및 계약서류 안내드릴 예정입니다. (약 3영업일 소요)



- 토스페이먼츠는 일반결제와 허브형 간편결제용 MID가 개발 발급되므로, 추가 설정하시어 pg파라미터에 MID를 지정하여 요청하도록 구현 부탁 드립니다.
- [허브형 간편결제 이용 방법 보러가기 ↗](https://help-center-portone.vercel.app/content/hub-service-fee)
- [토스페이먼츠\_간편결제 연동 방법 ↗](https://guide.portone.io/67330b1b-24a9-444a-a394-a2783e8876a2)
- [토스페이먼츠\_애플페이 이용 방법 보러가기 ↗ ](https://guide.portone.io/67330b1b-24a9-444a-a394-a2783e8876a2)
